package com.zskk.dicom.monitor.queue;

import com.zskk.dicom.monitor.config.Configs;

import java.util.ArrayList;
import java.util.List;

/**
 * 队列基类
 * @param <T>
 */
public class BaseQueue<T> implements IQueue<T>{

    private List<T> queue = null;
    private String flag = null;
    public BaseQueue(String flag) {
        this.queue = new ArrayList<>();
        this.flag = flag;
    }

    @Override
    public int size() {
        checkSecurity();
        return this.queue.size();
    }

    @Override
    public T pop() {
        checkSecurity();
        if(size() == 0) {
            return null;
        }
        return this.queue.remove(0);
    }

    @Override
    public T peek() {
        checkSecurity();
        if(size() == 0) {
            return null;
        }
        return this.queue.get(0);
    }

    @Override
    public boolean push(T t) {
        checkSecurity();
        if(this.queue.contains(t)) {
            return false;
        }
        return this.queue.add(t);
    }

    @Override
    public boolean empty() {
        checkSecurity();
        return this.queue.size() == 0;
    }

    /**
     * 安全校验 队列arraylist是否被初始化
     */
    private void checkSecurity() {
        if(this.queue == null) {
            Configs.sysLog.error("queue error：" + this.flag + "\t queue is null");
            throw new Error("队列:" + this.flag + "没有被初始化");
        }
    }
}
