package com.zskk.dicom.monitor.runner;

import com.zskk.dicom.monitor.config.Configs;
import com.zskk.dicom.monitor.queue.CurrentRetryUploadQueue;
import com.zskk.dicom.monitor.queue.ErrorQueue;
import com.zskk.dicom.monitor.queue.SuccessQueue;
import com.zskk.dicom.monitor.uploader.BaseFileUploader;

import java.util.concurrent.TimeUnit;

public class RetryCurrentUploadRunner extends AbstractUpload implements Runnable{
    @Override
    protected boolean upload(String filePath) {
        return BaseFileUploader.upload(filePath, SuccessQueue.getInstance(), ErrorQueue.getInstance());
    }

    @Override
    protected String getUploadFilePath() {
        return (String) CurrentRetryUploadQueue.getInstance().pop();
    }

    @Override
    public void run() {
        while(true) {
            try {
                if(CurrentRetryUploadQueue.getInstance().empty()) {
                    Configs.sysLog.warn("CurrentRetryUploadQueue is empty");
                    TimeUnit.SECONDS.sleep(10);
                }
                if(upload()) {
                    Configs.sysLog.info("RetryCurrentUploadRunner upload success");
                    TimeUnit.MILLISECONDS.sleep(10);
                } else {
                    Configs.sysLog.warn("RetryCurrentUploadRunner upload fail");
                    TimeUnit.SECONDS.sleep(1);
                }
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
    }
}
